# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/resource/template_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3nebius/msp/v1alpha1/resource/template_service.proto\x12\x1cnebius.msp.v1alpha1.resource\x1a+nebius/msp/v1alpha1/resource/template.proto\"o\n\x14ListTemplatesRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x1b\n\tparent_id\x18\x03 \x01(\tR\x08parentId\"}\n\x15ListTemplatesResponse\x12<\n\x05items\x18\x01 \x03(\x0b\x32&.nebius.msp.v1alpha1.resource.TemplateR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x82\x01\n\x0fTemplateService\x12o\n\x04List\x12\x32.nebius.msp.v1alpha1.resource.ListTemplatesRequest\x1a\x33.nebius.msp.v1alpha1.resource.ListTemplatesResponseBy\n#ai.nebius.pub.msp.v1alpha1.resourceB\x14TemplateServiceProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.resource.template_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.msp.v1alpha1.resourceB\024TemplateServiceProtoP\001Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resource'
  _globals['_LISTTEMPLATESREQUEST']._serialized_start=130
  _globals['_LISTTEMPLATESREQUEST']._serialized_end=241
  _globals['_LISTTEMPLATESRESPONSE']._serialized_start=243
  _globals['_LISTTEMPLATESRESPONSE']._serialized_end=368
  _globals['_TEMPLATESERVICE']._serialized_start=371
  _globals['_TEMPLATESERVICE']._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/filesystem_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as nebius_dot_common_dot_v1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1 import filesystem_pb2 as nebius_dot_compute_dot_v1_dot_filesystem__pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as nebius_dot_compute_dot_v1_dot_operation__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/compute/v1/filesystem_service.proto\x12\x11nebius.compute.v1\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a(nebius/common/v1/operation_service.proto\x1a\"nebius/compute/v1/filesystem.proto\x1a)nebius/compute/v1/operation_service.proto\"&\n\x14GetFilesystemRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x89\x01\n\x16ListFilesystemsRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x90\x01\n\x17\x43reateFilesystemRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.compute.v1.FilesystemSpecR\x04spec\"\x90\x01\n\x17UpdateFilesystemRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.compute.v1.FilesystemSpecR\x04spec\")\n\x17\x44\x65leteFilesystemRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"v\n\x17ListFilesystemsResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32\x1d.nebius.compute.v1.FilesystemR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x80\x05\n\x11\x46ilesystemService\x12M\n\x03Get\x12\'.nebius.compute.v1.GetFilesystemRequest\x1a\x1d.nebius.compute.v1.Filesystem\x12N\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x1d.nebius.compute.v1.Filesystem\x12]\n\x04List\x12).nebius.compute.v1.ListFilesystemsRequest\x1a*.nebius.compute.v1.ListFilesystemsResponse\x12Q\n\x06\x43reate\x12*.nebius.compute.v1.CreateFilesystemRequest\x1a\x1b.nebius.common.v1.Operation\x12Q\n\x06Update\x12*.nebius.compute.v1.UpdateFilesystemRequest\x1a\x1b.nebius.common.v1.Operation\x12Q\n\x06\x44\x65lete\x12*.nebius.compute.v1.DeleteFilesystemRequest\x1a\x1b.nebius.common.v1.Operation\x12t\n\x16ListOperationsByParent\x12\x30.nebius.compute.v1.ListOperationsByParentRequest\x1a(.nebius.common.v1.ListOperationsResponseBe\n\x18\x61i.nebius.pub.compute.v1B\x16\x46ilesystemServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.filesystem_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\026FilesystemServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _globals['_GETFILESYSTEMREQUEST']._serialized_start=253
  _globals['_GETFILESYSTEMREQUEST']._serialized_end=291
  _globals['_LISTFILESYSTEMSREQUEST']._serialized_start=294
  _globals['_LISTFILESYSTEMSREQUEST']._serialized_end=431
  _globals['_CREATEFILESYSTEMREQUEST']._serialized_start=434
  _globals['_CREATEFILESYSTEMREQUEST']._serialized_end=578
  _globals['_UPDATEFILESYSTEMREQUEST']._serialized_start=581
  _globals['_UPDATEFILESYSTEMREQUEST']._serialized_end=725
  _globals['_DELETEFILESYSTEMREQUEST']._serialized_start=727
  _globals['_DELETEFILESYSTEMREQUEST']._serialized_end=768
  _globals['_LISTFILESYSTEMSRESPONSE']._serialized_start=770
  _globals['_LISTFILESYSTEMSRESPONSE']._serialized_end=888
  _globals['_FILESYSTEMSERVICE']._serialized_start=891
  _globals['_FILESYSTEMSERVICE']._serialized_end=1531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/gpu_cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.common.v1alpha1 import operation_service_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1alpha1 import gpu_cluster_pb2 as nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1nebius/compute/v1alpha1/gpu_cluster_service.proto\x12\x17nebius.compute.v1alpha1\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a.nebius/common/v1alpha1/operation_service.proto\x1a)nebius/compute/v1alpha1/gpu_cluster.proto\"&\n\x14GetGpuClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x89\x01\n\x16ListGpuClustersRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x96\x01\n\x17\x43reateGpuClusterRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.compute.v1alpha1.GpuClusterSpecR\x04spec\"\x96\x01\n\x17UpdateGpuClusterRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.compute.v1alpha1.GpuClusterSpecR\x04spec\")\n\x17\x44\x65leteGpuClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"|\n\x17ListGpuClustersResponse\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.nebius.compute.v1alpha1.GpuClusterR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xd2\x05\n\x11GpuClusterService\x12Y\n\x03Get\x12-.nebius.compute.v1alpha1.GetGpuClusterRequest\x1a#.nebius.compute.v1alpha1.GpuCluster\x12T\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a#.nebius.compute.v1alpha1.GpuCluster\x12i\n\x04List\x12/.nebius.compute.v1alpha1.ListGpuClustersRequest\x1a\x30.nebius.compute.v1alpha1.ListGpuClustersResponse\x12]\n\x06\x43reate\x12\x30.nebius.compute.v1alpha1.CreateGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12]\n\x06Update\x12\x30.nebius.compute.v1alpha1.UpdateGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12]\n\x06\x44\x65lete\x12\x30.nebius.compute.v1alpha1.DeleteGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x7f\n\x16ListOperationsByParent\x12\x35.nebius.common.v1alpha1.ListOperationsByParentRequest\x1a..nebius.common.v1alpha1.ListOperationsResponse\x1a\x03\x88\x02\x01\x42t\n\x1e\x61i.nebius.pub.compute.v1alpha1B\x16GpuClusterServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.gpu_cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\026GpuClusterServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _GPUCLUSTERSERVICE._options = None
  _GPUCLUSTERSERVICE._serialized_options = b'\210\002\001'
  _globals['_GETGPUCLUSTERREQUEST']._serialized_start=242
  _globals['_GETGPUCLUSTERREQUEST']._serialized_end=280
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_start=283
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_end=420
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_start=423
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_end=573
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_start=576
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_end=726
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_start=728
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_end=769
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_start=771
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_end=895
  _globals['_GPUCLUSTERSERVICE']._serialized_start=898
  _globals['_GPUCLUSTERSERVICE']._serialized_end=1620
# @@protoc_insertion_point(module_scope)



from collections.abc import Callable
from logging import getLogger
from time import time
from typing import TypeVar

from grpc import StatusCode
from grpc.aio._call import AioRpcError, UnaryUnaryCall
from grpc.aio._interceptor import ClientCallDetails, UnaryUnaryClientInterceptor
from grpc.aio._metadata import Metadata

from nebius.aio.authorization.options import get_options_from_metadata
from nebius.base.metadata import Authorization, Internal

from .authorization import Provider

log = getLogger(__name__)

Req = TypeVar("Req")
Res = TypeVar("Res")


class AuthorizationInterceptor(UnaryUnaryClientInterceptor):  # type: ignore[unused-ignore,misc]
    def __init__(self, provider: Provider) -> None:
        super().__init__()
        self._provider = provider

    async def intercept_unary_unary(
        self,
        continuation: Callable[[ClientCallDetails, Req], UnaryUnaryCall | Res],
        client_call_details: ClientCallDetails,
        request: Req,
    ) -> UnaryUnaryCall | Res:
        if client_call_details.metadata is None:
            client_call_details = ClientCallDetails(
                method=client_call_details.method,
                timeout=client_call_details.timeout,
                metadata=Metadata(),
                credentials=client_call_details.credentials,
                wait_for_ready=client_call_details.wait_for_ready,
            )
        auth_type = client_call_details.metadata.get(Internal.AUTHORIZATION.lower())  # type: ignore
        auth_options = get_options_from_metadata(client_call_details.metadata)
        if auth_type == Authorization.DISABLE:
            log.debug(
                f"Calling {client_call_details.method}," " authentication is disabled"
            )
            return await continuation(client_call_details, request)  # type: ignore

        log.debug(
            f"Authentication for {client_call_details.method} is enabled, "
            f"{auth_type=!r}, {auth_options=!r}."
        )
        start = time()
        deadline = None
        if client_call_details.timeout is not None:
            deadline = start + client_call_details.timeout
        attempt = 0
        auth = self._provider.authenticator()
        while True:
            attempt += 1
            timeout = None
            if deadline is not None:
                timeout = deadline - time()
            log.debug(
                f"Authenticating {client_call_details.method}, {attempt=}, "
                f"{timeout=}."
            )
            await auth.authenticate(
                client_call_details.metadata,  # type: ignore
                timeout,
                auth_options,
            )
            if deadline is not None:
                timeout = deadline - time()
                if timeout <= 0:
                    raise TimeoutError("authorization timed out")
                client_call_details = ClientCallDetails(
                    method=client_call_details.method,
                    timeout=timeout,
                    metadata=client_call_details.metadata,
                    credentials=client_call_details.credentials,
                    wait_for_ready=client_call_details.wait_for_ready,
                )
            try:
                log.debug(f"Calling authenticated {client_call_details.method}.")
                return await continuation(client_call_details, request)  # type: ignore
            except AioRpcError as e:
                if (
                    e.code() != StatusCode.UNAUTHENTICATED
                    or not auth.can_retry(e, auth_options)
                    or (deadline is not None and deadline <= time())
                ):
                    raise
                log.debug(
                    f"Call to {client_call_details.method},"
                    f" returned UNAUTHENTICATED, trying authentication again"
                )



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PythonConfig(_message.Message):
    __slots__ = ["requirements", "file_uris"]
    REQUIREMENTS_FIELD_NUMBER: _ClassVar[int]
    FILE_URIS_FIELD_NUMBER: _ClassVar[int]
    requirements: _containers.RepeatedScalarFieldContainer[str]
    file_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, requirements: _Optional[_Iterable[str]] = ..., file_uris: _Optional[_Iterable[str]] = ...) -> None: ...

class JavaConfig(_message.Message):
    __slots__ = ["entrypoint_class"]
    ENTRYPOINT_CLASS_FIELD_NUMBER: _ClassVar[int]
    entrypoint_class: str
    def __init__(self, entrypoint_class: _Optional[str] = ...) -> None: ...



from nebius.api.nebius import FieldBehavior
from nebius.api.nebius import field_behavior as fb_descriptor
from nebius.base.protos.compiler.descriptors import Field

_cache = dict[str, set[FieldBehavior]]()


def field_behavior(field: Field) -> set[FieldBehavior]:
    if field.full_type_name in _cache:
        return _cache[field.full_type_name]
    fb_array = field.descriptor.options.Extensions[fb_descriptor]  # type: ignore
    ret = set[FieldBehavior]()
    for fb in fb_array:  # type: ignore[unused-ignore]
        ret.add(FieldBehavior(fb))
    _cache[field.full_type_name] = ret
    return ret



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.mk8s.v1 import cluster_pb2 as nebius_dot_mk8s_dot_v1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/mk8s/v1/cluster_service.proto\x12\x0enebius.mk8s.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1cnebius/mk8s/v1/cluster.proto\"\x97\x01\n\x14\x43reateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x37\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.nebius.mk8s.v1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"V\n\x11GetClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\"v\n\x13ListClustersRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"m\n\x14ListClustersResponse\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x17.nebius.mk8s.v1.ClusterR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x8f\x01\n\x14UpdateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12/\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.nebius.mk8s.v1.ClusterSpecR\x04spec\".\n\x14\x44\x65leteClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xd7\x03\n\x0e\x43lusterService\x12\x41\n\x03Get\x12!.nebius.mk8s.v1.GetClusterRequest\x1a\x17.nebius.mk8s.v1.Cluster\x12H\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x17.nebius.mk8s.v1.Cluster\x12Q\n\x04List\x12#.nebius.mk8s.v1.ListClustersRequest\x1a$.nebius.mk8s.v1.ListClustersResponse\x12K\n\x06\x43reate\x12$.nebius.mk8s.v1.CreateClusterRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x06Update\x12$.nebius.mk8s.v1.UpdateClusterRequest\x1a\x1b.nebius.common.v1.Operation\x12K\n\x06\x44\x65lete\x12$.nebius.mk8s.v1.DeleteClusterRequest\x1a\x1b.nebius.common.v1.OperationB\\\n\x15\x61i.nebius.pub.mk8s.v1B\x13\x43lusterServiceProtoP\x01Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025ai.nebius.pub.mk8s.v1B\023ClusterServiceProtoP\001Z,github.com/nebius/gosdk/proto/nebius/mk8s/v1'
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERREQUEST.fields_by_name['id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETECLUSTERREQUEST.fields_by_name['id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CREATECLUSTERREQUEST']._serialized_start=183
  _globals['_CREATECLUSTERREQUEST']._serialized_end=334
  _globals['_GETCLUSTERREQUEST']._serialized_start=336
  _globals['_GETCLUSTERREQUEST']._serialized_end=422
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=424
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=542
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=544
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=653
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=656
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=799
  _globals['_DELETECLUSTERREQUEST']._serialized_start=801
  _globals['_DELETECLUSTERREQUEST']._serialized_end=847
  _globals['_CLUSTERSERVICE']._serialized_start=850
  _globals['_CLUSTERSERVICE']._serialized_end=1321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/resource/preset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/msp/v1alpha1/resource/preset.proto\x12\x1cnebius.msp.v1alpha1.resource\x1a\x1b\x62uf/validate/validate.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"N\n\x06Preset\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.PresetSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xe4\x01\n\nPresetSpec\x12H\n\x06\x66lavor\x18\x01 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.FlavorSpecB\x06\xbaH\x03\xc8\x01\x01R\x06\x66lavor\x12\x38\n\x05hosts\x18\x02 \x01(\x0b\x32\".nebius.msp.v1alpha1.resource.HostR\x05hosts\x12\x36\n\x04\x64isk\x18\x03 \x01(\x0b\x32\".nebius.msp.v1alpha1.resource.DiskR\x04\x64isk\x12\x1a\n\x04role\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04role\"\x97\x01\n\nFlavorSpec\x12?\n\x03\x63pu\x18\x01 \x01(\x0b\x32%.nebius.msp.v1alpha1.resource.CpuSpecB\x06\xbaH\x03\xc8\x01\x01R\x03\x63pu\x12H\n\x06memory\x18\x02 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.MemorySpecB\x06\xbaH\x03\xc8\x01\x01R\x06memory\"O\n\x07\x43puSpec\x12\x1c\n\x05\x63ount\x18\x01 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\x05\x63ount\x12&\n\ngeneration\x18\x02 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\ngeneration\"=\n\nMemorySpec\x12/\n\x0flimit_gibibytes\x18\x01 \x01(\x03\x42\x06\xbaH\x03\xc8\x01\x01R\x0elimitGibibytesBp\n#ai.nebius.pub.msp.v1alpha1.resourceB\x0bPresetProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.resource.preset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.msp.v1alpha1.resourceB\013PresetProtoP\001Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resource'
  _PRESET.fields_by_name['spec']._options = None
  _PRESET.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _PRESETSPEC.fields_by_name['flavor']._options = None
  _PRESETSPEC.fields_by_name['flavor']._serialized_options = b'\272H\003\310\001\001'
  _PRESETSPEC.fields_by_name['role']._options = None
  _PRESETSPEC.fields_by_name['role']._serialized_options = b'\272H\003\310\001\001'
  _FLAVORSPEC.fields_by_name['cpu']._options = None
  _FLAVORSPEC.fields_by_name['cpu']._serialized_options = b'\272H\003\310\001\001'
  _FLAVORSPEC.fields_by_name['memory']._options = None
  _FLAVORSPEC.fields_by_name['memory']._serialized_options = b'\272H\003\310\001\001'
  _CPUSPEC.fields_by_name['count']._options = None
  _CPUSPEC.fields_by_name['count']._serialized_options = b'\272H\003\310\001\001'
  _CPUSPEC.fields_by_name['generation']._options = None
  _CPUSPEC.fields_by_name['generation']._serialized_options = b'\272H\003\310\001\001'
  _MEMORYSPEC.fields_by_name['limit_gibibytes']._options = None
  _MEMORYSPEC.fields_by_name['limit_gibibytes']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PRESET']._serialized_start=149
  _globals['_PRESET']._serialized_end=227
  _globals['_PRESETSPEC']._serialized_start=230
  _globals['_PRESETSPEC']._serialized_end=458
  _globals['_FLAVORSPEC']._serialized_start=461
  _globals['_FLAVORSPEC']._serialized_end=612
  _globals['_CPUSPEC']._serialized_start=614
  _globals['_CPUSPEC']._serialized_end=693
  _globals['_MEMORYSPEC']._serialized_start=695
  _globals['_MEMORYSPEC']._serialized_end=756
# @@protoc_insertion_point(module_scope)
